==> amity-sdk-6.50.2-sources.jar: main/com/amity/socialcloud/sdk/core/session/component/UserSettingSessionComponent.kt <==
package com.amity.socialcloud.sdk.core.session.component

import com.amity.socialcloud.sdk.core.data.settings.network.NetworkSettingsRepository
import com.amity.socialcloud.sdk.core.session.eventbus.SessionLifeCycleEventBus
import com.amity.socialcloud.sdk.core.session.eventbus.SessionStateEventBus
import com.amity.socialcloud.sdk.core.session.model.SessionState
import com.ekoapp.ekosdk.internal.data.model.EkoAccount
import io.reactivex.rxjava3.schedulers.Schedulers

class UserSettingSessionComponent(
    sessionLifeCycleEventBus: SessionLifeCycleEventBus,
    sessionStateEventBus: SessionStateEventBus
) :
    SessionComponent(
        sessionLifeCycleEventBus, sessionStateEventBus
    ) {
    override fun onSessionStateChange(sessionState: SessionState) {
        // nothing
    }

    override fun establish(account: EkoAccount) {
        fetchChatSettings()
        fetchSocialSettings()
        fetchUserSettings()
    }

    override fun destroy() {
        //nothing
    }

    override fun handleTokenExpire() {
        //nothing
    }

    //copy from old SessionObserver class
    private fun fetchChatSettings() {
        NetworkSettingsRepository()
            .getChatSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }

    private fun fetchSocialSettings() {
        NetworkSettingsRepository()
            .getSocialSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }

    private fun fetchUserSettings() {
        NetworkSettingsRepository()
            .getUserSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }
}

==> amity-sdk-7.11.1-sources.jar: main/com/amity/socialcloud/sdk/core/session/component/UserSettingSessionComponent.kt <==
package com.amity.socialcloud.sdk.core.session.component

import com.amity.socialcloud.sdk.api.core.AmityCoreClient
import com.amity.socialcloud.sdk.core.data.settings.network.NetworkSettingsRepository
import com.amity.socialcloud.sdk.core.session.eventbus.SessionLifeCycleEventBus
import com.amity.socialcloud.sdk.core.session.eventbus.SessionStateEventBus
import com.amity.socialcloud.sdk.core.session.model.SessionState
import com.amity.socialcloud.sdk.model.core.user.AmityUserType
import com.ekoapp.ekosdk.internal.data.model.EkoAccount
import io.reactivex.rxjava3.schedulers.Schedulers

class UserSettingSessionComponent(
    sessionLifeCycleEventBus: SessionLifeCycleEventBus,
    sessionStateEventBus: SessionStateEventBus
) :
    SessionComponent(
        sessionLifeCycleEventBus, sessionStateEventBus
    ) {
    override fun onSessionStateChange(sessionState: SessionState) {
        // nothing
    }

    override fun establish(account: EkoAccount) {
        if (AmityCoreClient.getCurrentUserType() == AmityUserType.SIGNED_IN) {
            fetchChatSettings()
            fetchSocialSettings()
            fetchUserSettings()
        }
    }

    override fun destroy() {
        //nothing
    }

    override fun handleTokenExpire() {
        //nothing
    }

    //copy from old SessionObserver class
    private fun fetchChatSettings() {
        NetworkSettingsRepository()
            .getChatSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }

    private fun fetchSocialSettings() {
        NetworkSettingsRepository()
            .getSocialSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }

    private fun fetchUserSettings() {
        NetworkSettingsRepository()
            .getUserSettings()
            .subscribeOn(Schedulers.io())
            .doOnError {
                // do nothing
            }
            .subscribe()
    }
}
